*Lista comandi*

/spot: Pone il bot in ascolto di uno spot\. Rispondi per inviare una richiesta di approvazione al messaggio che vorresti spottare\.

/cancel: Annulla la procedura per la creazione dello spot in corso e cancella l'ultimo spot inviato ancora in valutazione, permettendoti di proporre un nuovo spot immediatamente\.

/rules: Mostra l'elenco di regole da rispettare nell'invio degli spot\.

/settings: Decidi se vuoi pubblicare in forma anonima o vuoi che il post faccia riferimento a te\. Di default è anonimo